@@ -1,6 +1,6 @@
 package App::size_dir_diff;
 
-our $VERSION = 0.3.4;
+our $VERSION = 0.3.5;
 
 =head1 NAME
 
@@ -16,7 +16,7 @@ Jonas Jensen
 
 =head1 LICENSE
 
-gpl_2
+GPL_2
 
 =cut
 
